==> qtjambi-networkauth-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiNetworkAuth/QOAuthHttpServerReplyHandler_shell.h <==
#ifndef QOAUTHHTTPSERVERREPLYHANDLER_SHELL_H
#define QOAUTHHTTPSERVERREPLYHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qoauthhttpserverreplyhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtJambi/RegistryAPI>


class QOAuthHttpServerReplyHandler_shell : public QOAuthHttpServerReplyHandler, public QtJambiShellInterface
{
public:
    QOAuthHttpServerReplyHandler_shell(QObject* parent0 = nullptr);
    QOAuthHttpServerReplyHandler_shell(const QHostAddress& address0, quint16 port1, QObject* parent2 = nullptr);
    QOAuthHttpServerReplyHandler_shell(quint16 port0, QObject* parent1 = nullptr);
    ~QOAuthHttpServerReplyHandler_shell() override;

    QString callback() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void networkReplyFinished(QNetworkReply* reply0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOAuthHttpServerReplyHandler_access : public QOAuthHttpServerReplyHandler
{
    jstring __qt_callback(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QOAUTHHTTPSERVERREPLYHANDLER_SHELL_H

==> qtjambi-networkauth-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiNetworkAuth/QOAuthHttpServerReplyHandler_shell.h <==
#ifndef QOAUTHHTTPSERVERREPLYHANDLER_SHELL_H
#define QOAUTHHTTPSERVERREPLYHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qoauthhttpserverreplyhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtJambi/RegistryAPI>


class QOAuthHttpServerReplyHandler_shell : public QOAuthHttpServerReplyHandler, public QtJambiShellInterface
{
public:
    QOAuthHttpServerReplyHandler_shell(QObject* parent0 = nullptr);
    QOAuthHttpServerReplyHandler_shell(const QHostAddress& address0, quint16 port1, QObject* parent2 = nullptr);
    QOAuthHttpServerReplyHandler_shell(quint16 port0, QObject* parent1 = nullptr);
    ~QOAuthHttpServerReplyHandler_shell() override;

    QString callback() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void networkReplyFinished(QNetworkReply* reply0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOAuthHttpServerReplyHandler_access : public QOAuthHttpServerReplyHandler
{
    jstring __qt_callback(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QOAUTHHTTPSERVERREPLYHANDLER_SHELL_H
